@@ -16,7 +16,7 @@
 #   Pressing on "Record" imediately starts to record accelerometer data (not smooth; raw data) until the user presses:
 #              "stop", it then opens a dialog to select where to save the data
 #              "clear", sweeps the recording buffer and continues recording
-#   Pressing on "open" will trigger an Open File dialog to open a file previously saved.. after succesful loading the user may press:
+#   Pressing on "open" will trigger an Open File dialog to open a file previously saved.. after successful loading the user may press:
 #               "Play/Pause" in order to view a playback of the loaded data
 #               "Close", to close the file and go back to the main screen
 #               Slide the TimeScale to change the display frequency
@@ -29,7 +29,7 @@ import hildon
 import gtk
 import osso
 import time
-
+#from portrait import FremantleRotation
 import gobject
 
 import math
@@ -45,8 +45,9 @@ class accDisplay (hildon.Window):
 	
 	def __init__(self):
 		hildon.Window.__init__ (self)
-
+		#FremantleRotation('accDisplay',self)
 		self.running = True
+		self.idle = False
 		self.last_read = [0,0,0]
 
 		self.appState = AppState.LIVE
@@ -61,15 +62,22 @@ class accDisplay (hildon.Window):
 		self.build_gui()
 		self.show()
 		self.connect("delete-event",self.on_close)
+		self.connect("focus-in-event",self.on_infocus)
+		self.connect("focus-out-event",self.on_outfocus)
 
 		while gtk.events_pending():
 			gtk.main_iteration(False)
-		
-		#self.be = jumpBE.JumpBe()
+
 		self.main_loop()
 
 	def main_loop(self):
 		while self.running:
+			if self.idle and not self.appState == AppState.RECORDING:
+				while gtk.events_pending():
+					gtk.main_iteration(False)
+				#print "idle"
+				time.sleep(0.3)
+				continue
 			if (not self.paused) or (not self.appState == AppState.PLAYBACK):
 				time.sleep(self.period);
 				if self.smoothFlag:
@@ -239,7 +247,12 @@ class accDisplay (hildon.Window):
 			filename = self.get_save_fn()
 			if filename != "":
 				fw = accFileIF.AccFileIF()
-				fw.Save(self.data_storage,filename)
+				if fw.Save(self.data_storage,filename):
+					hildon.hildon_banner_show_information(self, '', "Data file saved successfully!")
+				else:
+					hildon.hildon_banner_show_information(self, '', "Could not save data file, aborting! (Check permissions)")
+			else:
+				hildon.hildon_banner_show_information(self, '', "Saving aborted!")
 			##going back to LIVE even if user aborts the saving process
 			self.appState = AppState.LIVE
 		elif self.appState == AppState.PLAYBACK:
@@ -256,10 +269,14 @@ class accDisplay (hildon.Window):
 			if filename != "":
 				fw = accFileIF.AccFileIF()
 				self.tstamp,self.data_storage = fw.Load(filename)
-				self.time_scale.set_value(20)
-				self.time_scale.set_sensitive(True)
-				self.data_ptr = 0
-				self.appState = AppState.PLAYBACK
+				if self.data_storage == []:
+					hildon.hildon_banner_show_information(self, '', "Could not load data file!")
+				else:
+					hildon.hildon_banner_show_information(self, '', "Data file loaded successfully!")
+					self.time_scale.set_value(20)
+					self.time_scale.set_sensitive(True)
+					self.data_ptr = 0
+					self.appState = AppState.PLAYBACK
 			##only going to PLAYBACK if open process was successful
 		elif self.appState == AppState.RECORDING:
 			self.data_storage = []
@@ -281,6 +298,12 @@ class accDisplay (hildon.Window):
 	####################################################
 	def create_menu(self):
 		menu = hildon.AppMenu()
+		self.help_menu_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+		label = 'Help'
+		self.help_menu_button.set_label(label)
+		self.help_menu_button.connect("clicked", self.on_help)
+		menu.append(self.help_menu_button)
+		
 		self.ab_menu_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
 		label = 'About'
 		self.ab_menu_button.set_label(label)
@@ -298,19 +321,31 @@ class accDisplay (hildon.Window):
 	############## Normal Callbacks #####################
 	#####################################################
 	def on_close(self, *args):
+		self.idle = False
 		self.running = False
 
+	def on_infocus(self, *args):
+		self.idle = False
+		#print "In focus"
+	
+	def on_outfocus(self, *args):
+		self.idle = True
+		#print "Out of focus"
+
 	def on_about(self, *args):
 		dialog = gtk.AboutDialog()
 		dialog.set_name("accDisplay")
 		dialog.set_logo_icon_name("accDisplay")
 		dialog.set_comments('Accelerometers View/Record/Playback')
-		dialog.set_version("0.1")
+		dialog.set_version("0.7")
 		dialog.set_copyright("By Clovis Peruchi Scotti (aka cpscotti)")
 		dialog.set_website("www.das.ufsc.br/~scotti")
 		dialog.connect ("response", lambda d, r: d.destroy())
 		dialog.show()
 
+	def on_help(self, *args):
+		import acc_help
+		acc_help.Help()
 
 	###################################################
 	############### file choser dialogs.. #############
@@ -347,9 +382,12 @@ class accDisplay (hildon.Window):
 ############## Accel reading function #############
 ###################################################
 def acc_read():
-	f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
-	coords = [int(w) for w in f.readline().split()]
-	f.close()
+	try:
+		f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
+		coords = [int(w) for w in f.readline().split()]
+		f.close()
+	except Exception:
+		coords = [0.5,0.5,0.5]
 	return coords
 
 if __name__ == "__main__":
